==> open-xchange-core_7.10.3.orig.tar.bz2: open-xchange-core-7.10.3/com.openexchange.gdpr.dataexport/src/com/openexchange/gdpr/dataexport/DataExportSink.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.gdpr.dataexport;

import java.io.InputStream;
import java.util.Optional;
import org.json.JSONObject;
import com.openexchange.exception.OXException;

/**
 * {@link DataExportSink} - The export sink, which is used passed to providers to output their data and to signal changes.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @since v7.10.3
 */
public interface DataExportSink {

    /**
     * Exports given item's data
     *
     * @param data The item's data
     * @param item The item
     * @return <code>true</code> if item's data has been successfully written to this sink;
     *         otherwise <code>false</code> if write attempt has been denied (typically because task has been canceled meanwhile)
     * @throws OXException If export fails
     */
    boolean export(InputStream data, Item item) throws OXException;

    /**
     * Exports given directory (marker).
     *
     * @param data The item's data
     * @param directory The directory
     * @return <code>true</code> if item's data has been successfully written to this sink;
     *         otherwise <code>false</code> if write attempt has been denied (typically because task has been canceled meanwhile)
     * @throws OXException If export fails
     */
    boolean export(Directory directory) throws OXException;

    /**
     * Finishes the export and closes resources.
     *
     * @return The optional file storage location if successfully finished; otherwise an empty instance if already finished
     * @throws OXException If finishing fails
     */
    Optional<String> finish() throws OXException;

    /**
     * Revokes (by deleting) any export data written to this sink and closes resources.
     *
     * @throws OXException If revoking fails
     */
    void revoke() throws OXException;

    /**
     * Adds specified message to task's report.
     *
     * @param message The message to add
     * @throws OXException If message cannot be added to report
     */
    void addToReport(Message message) throws OXException;

    /**
     * Sets given save-point.
     *
     * @param jSavePoint The save-point to set
     * @throws OXException If setting save-point fails
     * @throws IllegalArgumentException If save-point is <code>null</code>
     */
    void setSavePoint(JSONObject jSavePoint) throws OXException;

    /**
     * Attempts to increment the fail count for sink-associated work item.
     *
     * @return <code>true</code> if successfully incremented; otherwise <code>false</code> if max. fail count already reached
     * @throws OXException If operation fails
     */
    boolean incrementFailCount() throws OXException;
}

==> open-xchange-core_7.10.4.orig.tar.bz2: open-xchange-core-7.10.4/com.openexchange.gdpr.dataexport/src/com/openexchange/gdpr/dataexport/DataExportSink.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.gdpr.dataexport;

import java.io.InputStream;
import java.util.Optional;
import org.json.JSONObject;
import com.openexchange.exception.OXException;

/**
 * {@link DataExportSink} - The export sink, which is used passed to providers to output their data and to signal changes.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @since v7.10.3
 */
public interface DataExportSink {

    /**
     * Exports given item's data
     *
     * @param data The item's data
     * @param item The item
     * @return <code>true</code> if item's data has been successfully written to this sink;
     *         otherwise <code>false</code> if write attempt has been denied (typically because task has been canceled meanwhile)
     * @throws OXException If export fails
     */
    boolean export(InputStream data, Item item) throws OXException;

    /**
     * Exports given directory (marker).
     *
     * @param data The item's data
     * @param directory The directory
     * @return The actual directory path if directory has been successfully written to this sink;
     *         otherwise <code>null</code> if write attempt has been denied (typically because task has been canceled meanwhile)
     * @throws OXException If export fails
     */
    String export(Directory directory) throws OXException;

    /**
     * Finishes the export and closes resources.
     *
     * @return The optional file storage location if successfully finished; otherwise an empty instance if already finished
     * @throws OXException If finishing fails
     */
    Optional<String> finish() throws OXException;

    /**
     * Revokes (by deleting) any export data written to this sink and closes resources.
     *
     * @throws OXException If revoking fails
     */
    void revoke() throws OXException;

    /**
     * Adds specified message to task's report.
     *
     * @param message The message to add
     * @throws OXException If message cannot be added to report
     */
    void addToReport(Message message) throws OXException;

    /**
     * Sets given save-point.
     *
     * @param jSavePoint The save-point to set
     * @throws OXException If setting save-point fails
     * @throws IllegalArgumentException If save-point is <code>null</code>
     */
    void setSavePoint(JSONObject jSavePoint) throws OXException;

    /**
     * Attempts to increment the fail count for sink-associated work item.
     *
     * @return <code>true</code> if successfully incremented; otherwise <code>false</code> if max. fail count already reached
     * @throws OXException If operation fails
     */
    boolean incrementFailCount() throws OXException;
}
